@@ -452,7 +452,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
 
   if (missing(group)) {
     
-    mydata <- gather(mydata, key = variable, value = value, UQS(syms(poll.orig)))
+    mydata <- gather(mydata, key = variable, value = value, poll.orig)
     mydata$variable <- factor(mydata$variable, levels = pollutant) ## drop unused factor levels
   } else {
     ## group needs to be 'variable' and pollutant 'value'
@@ -1138,7 +1138,8 @@ errorDiff <- function(mydata, vars = "day.hour", poll1, poll2, type, B = B,
   if (vars == "mnth") splits <- c("mnth", type)
 
   ## warnings from dplyr seem harmless FIXME
-  res <- group_by(mydata, UQS(syms(splits))) %>%
+  res <- mydata %>% 
+    group_by(across(splits)) %>%
     do(bootMeanDiff(., x = poll1, y = poll2, B = B))
 
   # make sure we keep the order correct
