@@ -673,7 +673,8 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
   }
 
 
-  results <- group_by(mydata, UQS(syms(type))) %>%
+  results <- mydata %>% 
+    group_by(across(type)) %>%
     do(prepare.grid(.))
 
   ## format
@@ -708,7 +709,8 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
 
   ## correction for bias when angle does not divide exactly into 360
   if (bias.corr) {
-    results <- group_by(results, UQS(syms(type))) %>%
+    results <- results %>% 
+      group_by(across(type)) %>%
       do(corr_bias(.))
   }
 
@@ -776,8 +778,9 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
   temp <- paste(type, collapse = "+")
   myform <- formula(paste("Interval1 ~ wd | ", temp, sep = ""))
 
-  mymax <- 2 * max.freq
-
+  # maximum annotation that covers the data
+  mymax <- max(pretty(c(0, max.freq), 4))
+  
   # check to see if grid.line is a list or not and set grid line properties
   grid.value <- NULL
 
@@ -805,7 +808,7 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
     grid.col <- "grey85"
   }
 
-  myby <- if (is.null(grid.value)) pretty(c(0, mymax), 10)[2] else grid.value
+  myby <- if (is.null(grid.value)) pretty(c(0, mymax), 4)[2] else grid.value
 
   if (myby / mymax > 0.9) myby <- mymax * 0.9
 
@@ -830,7 +833,7 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
       panel.xyplot(x, y, ...)
       angles <- seq(0, 2 * pi, length = 360)
       sapply(
-        seq(off.set, mymax, by = myby),
+        seq(off.set, mymax + off.set, by = myby),
         function(x) llines(
             x * sin(angles), x * cos(angles),
             col = grid.col, lwd = 1,
@@ -843,15 +846,6 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
       
       upper <- max.freq + off.set
       
-      ## add axis lines
-      lsegments(-upper, 0, upper, 0)
-      lsegments(0, -upper, 0, upper)
-      
-      ltext(upper * -1 * 0.95, 0.07 * upper, "W", cex = 0.7)
-      ltext(0.07 * upper, upper * -1 * 0.95, "S", cex = 0.7)
-      ltext(0.07 * upper, upper * 0.95, "N", cex = 0.7)
-      ltext(upper * 0.95, 0.07 * upper, "E", cex = 0.7)
-      
       if (nrow(dat) > 0) {
         dat$Interval0 <- 0 ## make a lower bound to refer to
         
@@ -877,8 +871,8 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
       }
       
       ltext(
-        seq((myby + off.set), mymax, myby) * sin(pi * angle.scale / 180),
-        seq((myby + off.set), mymax, myby) * cos(pi * angle.scale / 180),
+        seq((myby + off.set), (mymax + off.set), myby) * sin(pi * angle.scale / 180),
+        seq((myby + off.set), (mymax + off.set), myby) * cos(pi * angle.scale / 180),
         paste(seq(myby, mymax, by = myby), stat.unit, sep = ""),
         cex = 0.7
       )
@@ -927,6 +921,15 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
           adj = c(1, 0), cex = 0.7, col = calm.col
         )        
         
+        ## add axis lines
+        lsegments(-upper, 0, upper, 0)
+        lsegments(0, -upper, 0, upper)
+        
+        ltext(upper * -1 * 0.95, 0.07 * upper, "W", cex = 0.7)
+        ltext(0.07 * upper, upper * -1 * 0.95, "S", cex = 0.7)
+        ltext(0.07 * upper, upper * 0.95, "N", cex = 0.7)
+        ltext(upper * 0.95, 0.07 * upper, "E", cex = 0.7)
+        
       }
     }, legend = legend
   )
